import java.awt.Rectangle;
import java.lang.RuntimeException;
import javax.swing.JFrame;
import java.awt.Dimension;
import javax.swing.JPanel;
import javax.swing.WindowConstants;
import java.awt.Graphics;
import java.awt.Point;
import java.util.Vector;
import java.awt.Color;

/**
 * repr&eacute;sentation d'une grille du plan &agrave; coordonn&eacute;es
 * enti&egrave;res, longueur et hauteur strictement positives et cases
 * num&eacute;rot&eacute;es (i, j) pour i&ge;0 et i&lt;largeur et j&ge;0 et
 * j&lt;hauteur
 */
public class Grille extends Rectangle{
    private Quadrillage quadrillage;

    private Grille(int largeur, int hauteur){
	super(largeur, hauteur);
	if(largeur<=0 || hauteur<=0)
	    throw new RuntimeException("les dimensions doivent etre >0");
	this.dessiner();
    }

    /**
     * fournit une nouvelle grille et la dessine
     * @param largeur,hauteur dimensions de la grille (doivent &ecirc;tre >0)
     * @return une grille aux bonnes dimensions
     */
    public static Grille uneGrille(int largeur, int hauteur){
	return new Grille(largeur, hauteur);
    }

    /**
     * renvoie la largeur de la grille fournie en argument
     * @param g une grille
     * @return la largeur de <code>g</code>
     */
    public static int getLargeur(Grille g){
	return (int)g.getWidth();
    }

    /**
     * renvoie la hauteur de la grille fournie en argument
     * @param g une grille
     * @return la hauteur de <code>g</code>
     */
    public static int getHauteur(Grille g){
	return (int)g.getHeight();
    }


    /**
     * dessine la grille
     */
    private void dessiner(){
	JFrame fenetre = new JFrame("une grille "+this.width+"x"+this.height);
	fenetre.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);

	quadrillage = new Quadrillage(this.width, this.height);
	fenetre.getContentPane().add(quadrillage);
	fenetre.pack();
	fenetre.setVisible(true);
	
    }

    private void placer(Point p){
	this.quadrillage.ajouterPoint(p);
    }


    /**
     * place un point graphiquement sur une grille
     * @param p le point à placer
     * @param g la grille
     */
    public static void placerPoint(MonPoint p, Grille g){
	g.placer(p);
    }

}


class Quadrillage extends JPanel{
    int largeur, hauteur;
    private final int COTE = 20;
    Vector<Point> points;

    public Quadrillage(int largeur, int hauteur){
	this.setPreferredSize(new Dimension(largeur*COTE, hauteur*COTE));
	this.largeur = largeur;
	this.hauteur = hauteur;
	this.points = new Vector<Point>();
    }

    public void paintComponent(Graphics g) {
	g.setColor(Color.BLACK);
 	for(int i = 0; i<this.largeur;i++) // lignes verticales
	    g.drawLine(i*COTE, 0, i*COTE, hauteur*COTE);
	for(int i=0; i<this.hauteur; i++) // lignes horizontales
	    g.drawLine(0, i*COTE, largeur*COTE, i*COTE);
	g.setColor(Color.RED);
	for(int i=0; i<this.points.size(); i++){
	    Point p = this.points.elementAt(i);
	    g.fillArc(p.x*COTE-3,p.y*COTE-3,6,6,0,360);
	}
    }

    protected void ajouterPoint(Point p){
	this.points.add(p);
    }
}