import java.io.*;
import java.io.File;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Color;
import java.awt.image.BufferedImage;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import javax.imageio.ImageIO;

class Drawing {

    /**
      * drawPacMan() affiche un PacMan.
      */
    void drawPacMan() {
        graphics.setColor(Color.yellow);
    }

    /**
      * drawArc(angle, len) affiche un segment représentant le rayon d'un cercle
      * centré sur le milieu du dessin.
      *
      * @param angle
      *   L'angle du segment par rapport à l'horizontale (en degrés)
      * @param len
      *   La longueur du segment (en pixels)
      */
    void drawArc(int angle, int len) {
        double rangle = Math.toRadians((double) angle);
        int x = (int) (Math.cos(rangle) * (double) len);
        int y = (int) (Math.sin(rangle) * (double) len);
        graphics.drawLine(300, 300, 300 + x, 300 + y);
    }

    Graphics graphics;

    public void draw(Graphics2D g) {
        graphics = g;
        graphics.setColor(Color.white);
        graphics.fillRect(0, 0, 600, 600);
        drawPacMan();
    }

}

class Picture extends JFrame {

    class Surface extends JPanel {

        private Drawing drawing;

        public Surface (Drawing d) {
            drawing = d;
        }

        public void paintComponent (Graphics g) {
            Graphics2D g2d = (Graphics2D) g;
            super.paintComponent(g);
            drawing.draw(g2d);
        }
    }

    public Picture (String name, int width, int height) {
        setSize(width, height);
        setTitle(name);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);
    }

    public void draw(Drawing d) {
        add(new Surface(d));
        Runnable r = new Runnable() {
            public void run() {
                setVisible(true);
            }
        };

        SwingUtilities.invokeLater(r);
    }

}


class PacMan {

    public static void main(String[] args) {
        Picture picture = new Picture ("PacMan", 600, 600);
        Drawing drawing = new Drawing ();
        picture.draw(drawing);

    }

}
